#if !defined(_ADATA_PLATFORM_IOCTL_DFVXW_H)
#define _ADATA_PLATFORM_IOCTL_DFVXW_H

/*
** File: ioctl_dfvxw.h  
** Project: VxWorks Driver Framework
** Purpose: Definitions for special IOCTLs used by VxWorks Driver Framework.
**
** (C) Copyright Alpha Data 2009
**
** IOCTL fields are:
**
** ,-----------------------------------------------------------------------------------------------.
** |31 30 29 28|27 26 25 24 23 22|21 20 19 18 17 16|15 14 13 12 11 10|09|08|07 06 05 04 03 02 01 00|
** |-----------+-----------------+-----------------+-----------------+--+--+-----------------------|
** | 0  0  1  1| 0  0  0  0  0  0|A5 A4 A3 A2 A1 A0|B5 B4 B3 B2 B1 B0| S| N|C7 C6 C5 C4 C3 C2 C1 C0|
** |           |    (reserved)   |    out size     |     in size     |  |  |         code          |
** `-----------------------------------------------------------------------------------------------'
**
** Bits [31:28] are 0x3 because this is the range of IOCTL codes reserved for non-Wind River use.
** S = special IOCTL flag (e.g. DFVXW_IOCTLCODE_MMAP)
** N = non-blocking flag
*/

/* Macro to generate an IOCTL code as passed to 2nd argument of ioctl() */
#define DFVXW_MAX_IOCTL_SIZE (64)
#define DFVXW_MAKE_IOCTL(code, inSize, outSize) (0x30000000 | (code) | ((inSize) << 10) | ((outSize) << 16))
#define DFVXW_GET_IOCTLCODE(code) ((code) & 0x3FFU)
#define DFVXW_GET_IOCTLINSIZE(code) (((code) >> 10) & 0x3FU);
#define DFVXW_GET_IOCTLOUTSIZE(code) (((code) >> 16) & 0x3FU);

#define DFVXW_IOCTLCODE_SPECIAL  (0x200U)
#define DFVXW_IOCTLCODE_NONBLOCK (0x100U)

#define DFVXW_IOCTLCODE_MMAP     (0U | DFVXW_IOCTLCODE_SPECIAL)
#define DFVXW_IOCTLCODE_MUNMAP   (1U | DFVXW_IOCTLCODE_SPECIAL)
#define DFVXW_IOCTLCODE_CANCEL   (2U | DFVXW_IOCTLCODE_SPECIAL)
#define DFVXW_IOCTLCODE_FINISH   (3U | DFVXW_IOCTLCODE_SPECIAL)

typedef enum _DfVxwMmapStatus {
    DfVxwMmapSuccess = 0,
    DfVxwMmapInvalidRegion,
    DfVxwMmapNoMemory,
    DfVxwMmapRegionTooLarge,
    DfVxwMmapGeneralFailure
} DfVxwMmapStatus;

typedef union _DfVxwIoctlMmap {
  struct {
    uint32_t regionTag;
    uint64_t offset;
    uint64_t length;
  } in;
  struct {
    void* pVirtualBase;
  } out;
} DfVxwIoctlMmap;

typedef enum _DfVxwMunmapStatus {
    DfVxwMunmapSuccess = 0,
    DfVxwMunmapInvalidRegion,
    DfVxwMunmapGeneralFailure
} DfVxwMunmapStatus;

typedef union _DfVxwIoctlMunmap {
  struct {
    void* pVirtualBase;
  } in;
} DfVxwIoctlMunmap;

typedef enum _DfVxwCancelStatus {
  DfVxwCancelSuccess = 0
} DfVxwCancelStatus;

#endif
