/*
** File: vxw_entry.c  
** Project: VxWorks ADM-XRC monolithic driver entry point
** Purpose: Driver parameters
**
** (C) Copyright Alpha Data 2016
*/

#include "df.h"
#include "dfvxworks.h"

#include "admxrcDrv.h"

#define MATCH_EXACT (DF_PCI_MATCH_VENDOR | DF_PCI_MATCH_DEVICE | DF_PCI_MATCH_SUBVENDOR | DF_PCI_MATCH_SUBDEVICE)

static DfPciCompatibleId g_pciCompatibleIds[] = {
  { { 0x10b5U, 0x9080U, 0x4144U, 0x0040U, 0U }, MATCH_EXACT }, /* ADM-XRC / ADM-XRC-P */
  { { 0x10b5U, 0x9080U, 0x4144U, 0x0041U, 0U }, MATCH_EXACT }, /* ADM-XRC-II-Lite */
  { { 0x10b5U, 0x9080U, 0x4144U, 0x0042U, 0U }, MATCH_EXACT }, /* ADM-XRC-II */
  { { 0x4144U, 0x0043U, 0x4144U, 0x0047U, 0U }, MATCH_EXACT }, /* ADM-XPL (PCI) */
  { { 0x4144U, 0x0043U, 0x4144U, 0x0043U, 0U }, MATCH_EXACT }, /* ADM-XPL (PCI-X) */
  { { 0x4144U, 0x0044U, 0x4144U, 0x0044U, 0U }, MATCH_EXACT }, /* ADM-XP (PCI) */
  { { 0x4144U, 0x0044U, 0x4144U, 0x0048U, 0U }, MATCH_EXACT }, /* ADM-XP (PCI-X) */
  { { 0x10b5U, 0x9656U, 0x4144U, 0x0045U, 0U }, MATCH_EXACT }, /* ADP-WRC-II */
  { { 0x10b5U, 0x9656U, 0x4144U, 0x0046U, 0U }, MATCH_EXACT }, /* ADP-WRC-II */
  { { 0x4144U, 0x0049U, 0x4144U, 0x0049U, 0U }, MATCH_EXACT }, /* ADP-XPI (PCI) */
  { { 0x4144U, 0x0049U, 0x4144U, 0x004AU, 0U }, MATCH_EXACT }, /* ADP-XPI (PCI-X) */
  { { 0x10b5U, 0x9656U, 0x4144U, 0x004CU, 0U }, MATCH_EXACT }, /* ADM-XRC-4LX */
  { { 0x10b5U, 0x9656U, 0x4144U, 0x004DU, 0U }, MATCH_EXACT }, /* ADM-XRC-4SX */
  { { 0x4144U, 0x004EU, 0x4144U, 0x004EU, 0U }, MATCH_EXACT }, /* ADPE-XRC-4FX */
  { { 0x4144U, 0x004FU, 0x4144U, 0x004FU, 0U }, MATCH_EXACT }, /* ADM-XRC-4FX / ADM-XMC-4FX */
  { { 0x4144U, 0x0050U, 0x4144U, 0x0050U, 0U }, MATCH_EXACT }, /* ADM-XRC-5LX */
  { { 0x4144U, 0x0051U, 0x4144U, 0x0051U, 0U }, MATCH_EXACT }, /* ADM-XRC-5T1 */
  { { 0x4144U, 0x0052U, 0x4144U, 0x0052U, 0U }, MATCH_EXACT }, /* ADM-XRC-5T2 */
  { { 0x4144U, 0x0053U, 0x4144U, 0x0053U, 0U }, MATCH_EXACT }, /* ADM-XRC-5LXA */
  { { 0x4144U, 0x0054U, 0x4144U, 0x0054U, 0U }, MATCH_EXACT }, /* ADCP-XRC-4LX */
  { { 0x4144U, 0x0056U, 0x4144U, 0x0056U, 0U }, MATCH_EXACT }, /* ADM-AMC-5A2 */
  { { 0x4144U, 0x0057U, 0x4144U, 0x0057U, 0U }, MATCH_EXACT }, /* ADM-XRC-5TZ */
  { { 0x4144U, 0x0059U, 0x4144U, 0x0059U, 0U }, MATCH_EXACT }, /* ADC-BBP */
  { { 0x4144U, 0x005BU, 0x4144U, 0x005BU, 0U }, MATCH_EXACT }, /* ADM-XRC-5T2-ADV */
  { { 0x4144U, 0x005CU, 0x4144U, 0x005CU, 0U }, MATCH_EXACT }, /* ADM-XRC-5T-DA1 */
  { { 0x4144U, 0x005DU, 0x4144U, 0x005DU, 0U }, MATCH_EXACT }, /* ADM-XRC-5T1(V) */
  { { 0x4144U, 0x005FU, 0x4144U, 0x005FU, 0U }, MATCH_EXACT }, /* ADM-XRC-5T2-ADV6 */
  { { 0x4144U, 0x0060U, 0x4144U, 0x0060U, 0U }, MATCH_EXACT }, /* ADM-XRC-5T2-ADV-CC1 */
  { { 0x10b5U, 0x9056U, 0x4144U, 0x0080U, 0U }, MATCH_EXACT }, /* ADM-PCIE-6S1 */
  DF_PCI_COMPATIBLE_ID_END
};

static DfPciCompatibleId g_legacyPciCompatibleIds[] = {
  DF_PCI_COMPATIBLE_ID_END
};

/* Entry point for when built as downloadable module */
STATUS
admxrcDrvStart(
  int debugLevel)
{
#if defined(ADB3_VXBUS)
  return dfVxbEntry(debugLevel, "admxrc", g_pciCompatibleIds, g_legacyPciCompatibleIds, FALSE);
#else
  return dfVxwLegacyEntry(debugLevel, "admxrc", g_pciCompatibleIds, g_legacyPciCompatibleIds, FALSE);
#endif
}

/* Entry point with component parameters, used when building into kernel */
STATUS
admxrcDrvCompStart(
  int debugLevel,
  BOOL bEnableVpdWrite,
  BOOL bPciAddress64Bit,
  unsigned int numCommonBuffer,
  unsigned int commonBufferSize,
  unsigned int commonBufferAlign)
{
  admxrcDrvEnableVpdWrite = (unsigned int)bEnableVpdWrite;
  admxrcDrvPciAddress64Bit = (unsigned int)bPciAddress64Bit;
  admxrcDrvPrimaryCommonBufferCount = numCommonBuffer;
  admxrcDrvPrimaryCommonBufferAlignment = commonBufferAlign;
  admxrcDrvPrimaryCommonBufferSizeLow = commonBufferSize;
  
  return admxrcDrvStart(debugLevel);
}

STATUS
admxrcDrvStop(
  int debugLevel)
{
#if defined(ADB3_VXBUS)
  dfVxbExit();
#else
  dfVxwLegacyExit();
#endif
  return OK;
}
